@@ -1,7 +1,7 @@
 """
 Type annotations for mobile service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mobile/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
@@ -19,10 +19,15 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListBundlesPaginatorName", "ListProjectsPaginatorName", "Platform", "ProjectState")
+__all__ = (
+    "ListBundlesPaginatorName",
+    "ListProjectsPaginatorName",
+    "PlatformType",
+    "ProjectStateType",
+)
 
 
 ListBundlesPaginatorName = Literal["list_bundles"]
 ListProjectsPaginatorName = Literal["list_projects"]
-Platform = Literal["ANDROID", "JAVASCRIPT", "LINUX", "OBJC", "OSX", "SWIFT", "WINDOWS"]
-ProjectState = Literal["IMPORTING", "NORMAL", "SYNCING"]
+PlatformType = Literal["ANDROID", "JAVASCRIPT", "LINUX", "OBJC", "OSX", "SWIFT", "WINDOWS"]
+ProjectStateType = Literal["IMPORTING", "NORMAL", "SYNCING"]
